@@ -1,6 +1,7 @@
 use crypto_market_type::MarketType;
 
 use super::super::utils::calc_quantity_and_volume;
+use super::messages::WebsocketMsg;
 
 use crate::{MessageType, Order, OrderBookMsg, TradeMsg, TradeSide};
 
@@ -59,16 +60,6 @@ struct SwapTradeMsg {
     extra: HashMap<String, Value>,
 }
 
-#[derive(Serialize, Deserialize)]
-struct WebsocketMsg<T: Sized> {
-    time: i64,
-    channel: String,
-    event: String,
-    result: T,
-    #[serde(flatten)]
-    extra: HashMap<String, Value>,
-}
-
 pub(super) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     match market_type {
         MarketType::LinearFuture => {
