@@ -252,15 +252,15 @@ mod l2_orderbook {
 
         assert_eq!(orderbook.timestamp, 1622368000234);
 
-        assert_eq!(orderbook.bids[1].price, 35943.8);
-        assert_eq!(orderbook.bids[1].quantity_base, 6000.0 / 35943.8);
-        assert_eq!(orderbook.bids[1].quantity_quote, 6000.0);
-        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 60.0);
+        assert_eq!(orderbook.bids[0].price, 35943.8);
+        assert_eq!(orderbook.bids[0].quantity_base, 6000.0 / 35943.8);
+        assert_eq!(orderbook.bids[0].quantity_quote, 6000.0);
+        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 60.0);
 
-        assert_eq!(orderbook.bids[0].price, 35965.2);
-        assert_eq!(orderbook.bids[0].quantity_base, 89600.0 / 35965.2);
-        assert_eq!(orderbook.bids[0].quantity_quote, 89600.0);
-        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 896.0);
+        assert_eq!(orderbook.bids[1].price, 35965.2);
+        assert_eq!(orderbook.bids[1].quantity_base, 89600.0 / 35965.2);
+        assert_eq!(orderbook.bids[1].quantity_quote, 89600.0);
+        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 896.0);
 
         assert_eq!(orderbook.asks[0].price, 36038.3);
         assert_eq!(orderbook.asks[0].quantity_base, 900.0 / 36038.3);
@@ -291,20 +291,25 @@ mod l2_orderbook {
 
         assert_eq!(orderbook.timestamp, 1622368962065);
 
-        assert_eq!(orderbook.bids[1].price, 2437.04);
-        assert_eq!(orderbook.bids[1].quantity_base, 82.32);
-        assert_eq!(orderbook.bids[1].quantity_quote, 2437.04 * 82.32);
-        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 82.32);
+        assert_eq!(orderbook.bids[0].price, 2437.04);
+        assert_eq!(orderbook.bids[0].quantity_base, 82.32);
+        assert_eq!(orderbook.bids[0].quantity_quote, 2437.04 * 82.32);
+        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 82.32);
 
-        assert_eq!(orderbook.bids[0].price, 2437.07);
-        assert_eq!(orderbook.bids[0].quantity_base, 0.0);
-        assert_eq!(orderbook.bids[0].quantity_quote, 0.0);
-        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 0.0);
+        assert_eq!(orderbook.bids[1].price, 2437.07);
+        assert_eq!(orderbook.bids[1].quantity_base, 0.0);
+        assert_eq!(orderbook.bids[1].quantity_quote, 0.0);
+        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 0.0);
 
         assert_eq!(orderbook.asks[0].price, 2441.23);
         assert_eq!(orderbook.asks[0].quantity_base, 1.5);
         assert_eq!(orderbook.asks[0].quantity_quote, 2441.23 * 1.5);
         assert_eq!(orderbook.asks[0].quantity_contract.unwrap(), 1.5);
+
+        assert_eq!(orderbook.asks[1].price, 2441.24);
+        assert_eq!(orderbook.asks[1].quantity_base, 0.220);
+        assert_eq!(orderbook.asks[1].quantity_quote, 2441.24 * 0.220);
+        assert_eq!(orderbook.asks[1].quantity_contract.unwrap(), 0.220);
     }
 
     #[test]
@@ -325,15 +330,15 @@ mod l2_orderbook {
 
         assert_eq!(orderbook.timestamp, 1622371244687);
 
-        assert_eq!(orderbook.bids[1].price, 35729.77);
-        assert_eq!(orderbook.bids[1].quantity_base, 1.6);
-        assert_eq!(orderbook.bids[1].quantity_quote, 35729.77 * 1.6);
-        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 1.6);
+        assert_eq!(orderbook.bids[0].price, 35729.77);
+        assert_eq!(orderbook.bids[0].quantity_base, 1.6);
+        assert_eq!(orderbook.bids[0].quantity_quote, 35729.77 * 1.6);
+        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 1.6);
 
-        assert_eq!(orderbook.bids[0].price, 35750.0);
-        assert_eq!(orderbook.bids[0].quantity_base, 5.106);
-        assert_eq!(orderbook.bids[0].quantity_quote, 35750.0 * 5.106);
-        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 5.106);
+        assert_eq!(orderbook.bids[1].price, 35750.0);
+        assert_eq!(orderbook.bids[1].quantity_base, 5.106);
+        assert_eq!(orderbook.bids[1].quantity_quote, 35750.0 * 5.106);
+        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 5.106);
 
         assert_eq!(orderbook.asks[0].price, 35819.2);
         assert_eq!(orderbook.asks[0].quantity_base, 0.211);
@@ -364,15 +369,15 @@ mod l2_orderbook {
 
         assert_eq!(orderbook.timestamp, 1622370862553);
 
-        assert_eq!(orderbook.bids[1].price, 35365.9);
-        assert_eq!(orderbook.bids[1].quantity_base, 140000.0 / 35365.9);
-        assert_eq!(orderbook.bids[1].quantity_quote, 140000.0);
-        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 1400.0);
+        assert_eq!(orderbook.bids[0].price, 35365.9);
+        assert_eq!(orderbook.bids[0].quantity_base, 140000.0 / 35365.9);
+        assert_eq!(orderbook.bids[0].quantity_quote, 140000.0);
+        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 1400.0);
 
-        assert_eq!(orderbook.bids[0].price, 35425.8);
-        assert_eq!(orderbook.bids[0].quantity_base, 56100.0 / 35425.8);
-        assert_eq!(orderbook.bids[0].quantity_quote, 56100.0);
-        assert_eq!(orderbook.bids[0].quantity_contract.unwrap(), 561.0);
+        assert_eq!(orderbook.bids[1].price, 35425.8);
+        assert_eq!(orderbook.bids[1].quantity_base, 56100.0 / 35425.8);
+        assert_eq!(orderbook.bids[1].quantity_quote, 56100.0);
+        assert_eq!(orderbook.bids[1].quantity_contract.unwrap(), 561.0);
 
         assert_eq!(orderbook.asks[0].price, 35817.8);
         assert_eq!(orderbook.asks[0].quantity_base, 788500.0 / 35817.8);
